Crate gridmap

Crate gridmap 

Modules

cell
Trait to implement to cells inserted in the gridmap Cell trait
gridmap
GridMap of cells GridMap of cells
transform
Define how to transform a map Transform indexes given some parameters
util
Utility functions Utility functions

Type Aliases

Chunk
Chunk of cells